aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--sb600spi.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sb600spi.c b/sb600spi.c
index b1e140ba..94c4d9b4 100644
--- a/sb600spi.c
+++ b/sb600spi.c
@@ -130,9 +130,9 @@ static enum amd_chipset determine_generation(struct pci_dev *dev)
* found on both Stoney Ridge and Zen platforms.
*
* The revisions I have found by searching various lspci
* outputs are as follows: 0x4b, 0x59 & 0x61.
*/
- } else if (rev == 0x4b || rev == 0x51 || rev == 0x59 || rev == 0x61) {
+ } else if (rev == 0x4b || rev == 0x51 || rev == 0x59 || rev == 0x61 || rev == 0x71) {
msg_pdbg("Promontory (rev 0x%02x) detected.\n", rev);
return CHIPSET_PROMONTORY;
} else {
@@ -130,9 +130,9 @@ static enum amd_chipset determine_generation(struct pci_dev *dev)
*
* The revisions I have found by searching various lspci
- * outputs are as follows: 0x4b, 0x59 & 0x61.
+ * outputs are as follows: 0x4b, 0x59, 0x61 & 0x71.
*/